==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/TemperatureThreeQuarters.md <==
# TemperatureThreeQuarters


```text
fontawesome-6/Solid/TemperatureThreeQuarters
```

```text
include('fontawesome-6/Solid/TemperatureThreeQuarters')
```



| Illustration | TemperatureThreeQuarters |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/TemperatureThreeQuarters.png) | ![illustration for TemperatureThreeQuarters](../../fontawesome-6/Solid/TemperatureThreeQuarters.Local.png) |




## TemperatureThreeQuarters

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TemperatureThreeQuarters
include('fontawesome-6/Solid/TemperatureThreeQuarters')

' renders the element
TemperatureThreeQuarters('TemperatureThreeQuarters', 'Temperature Three Quarters', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TemperatureThreeQuarters
include('fontawesome-6/Solid/TemperatureThreeQuarters')

' renders the element
TemperatureThreeQuarters('TemperatureThreeQuarters', 'Temperature Three Quarters', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/TemperatureThreeQuarters.md <==
# TemperatureThreeQuarters


```text
fontawesome-6/Solid/TemperatureThreeQuarters
```

```text
include('fontawesome-6/Solid/TemperatureThreeQuarters')
```



| Illustration | TemperatureThreeQuarters |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/TemperatureThreeQuarters.png) | ![illustration for TemperatureThreeQuarters](../../fontawesome-6/Solid/TemperatureThreeQuarters.Local.png) |




## TemperatureThreeQuarters

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TemperatureThreeQuarters
include('fontawesome-6/Solid/TemperatureThreeQuarters')

' renders the element
TemperatureThreeQuarters('TemperatureThreeQuarters', 'Temperature Three Quarters', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element TemperatureThreeQuarters
include('fontawesome-6/Solid/TemperatureThreeQuarters')

' renders the element
TemperatureThreeQuarters('TemperatureThreeQuarters', 'Temperature Three Quarters', 'an optional tech label', 'an optional description')
@enduml
```
